diff --git a/NumLib/DOF/DOFTableUtil.cpp b/NumLib/DOF/DOFTableUtil.cpp
index e32477512874336734f18e3b44169aefcbdfd58a..0fb28cc278b5c0aa9a56eaa6b6e4c597dd14bd78 100644
--- a/NumLib/DOF/DOFTableUtil.cpp
+++ b/NumLib/DOF/DOFTableUtil.cpp
@@ -13,15 +13,16 @@
 namespace NumLib
 {
 std::vector<GlobalIndexType> getIndices(
-    std::size_t const id, NumLib::LocalToGlobalIndexMap const& dof_table)
+    std::size_t const mesh_item_id,
+    NumLib::LocalToGlobalIndexMap const& dof_table)
 {
-    assert(dof_table.size() > id);
+    assert(dof_table.size() > mesh_item_id);
     std::vector<GlobalIndexType> indices;
 
     // Local matrices and vectors will always be ordered by component
     // no matter what the order of the global matrix is.
     for (unsigned c = 0; c < dof_table.getNumberOfComponents(); ++c) {
-        auto const& idcs = dof_table(id, c).rows;
+        auto const& idcs = dof_table(mesh_item_id, c).rows;
         indices.reserve(indices.size() + idcs.size());
         indices.insert(indices.end(), idcs.begin(), idcs.end());
     }
diff --git a/ProcessLib/GroundwaterFlow/GroundwaterFlowFEM.h b/ProcessLib/GroundwaterFlow/GroundwaterFlowFEM.h
index d724bf7ef49b4db38b7e5022f0ac6315cf8bccea..1696df6804488e1e7a11fc2a7edb7c1eabcc378c 100644
--- a/ProcessLib/GroundwaterFlow/GroundwaterFlowFEM.h
+++ b/ProcessLib/GroundwaterFlow/GroundwaterFlowFEM.h
@@ -75,7 +75,7 @@ public:
         assert(local_matrix_size == ShapeFunction::NPOINTS * NUM_NODAL_DOF);
     }
 
-    void assemble(std::size_t const id,
+    void assemble(std::size_t const mesh_item_id,
                   NumLib::LocalToGlobalIndexMap const& dof_table,
                   double const /*t*/, GlobalVector const& x,
                   GlobalMatrix& /*M*/, GlobalMatrix& K,
@@ -83,7 +83,7 @@ public:
     {
         _localA.setZero();
         _localRhs.setZero();
-        auto const indices = NumLib::getIndices(id, dof_table);
+        auto const indices = NumLib::getIndices(mesh_item_id, dof_table);
         auto const local_x = x.get(indices);
 
         IntegrationMethod integration_method(_integration_order);
diff --git a/ProcessLib/LocalAssemblerInterface.h b/ProcessLib/LocalAssemblerInterface.h
index 56b46c3fc997fbb0dae69cc0de7b7d8313a7dc5d..3b4b0e7cac513a6bced4aac628f91ead76dd5d98 100644
--- a/ProcessLib/LocalAssemblerInterface.h
+++ b/ProcessLib/LocalAssemblerInterface.h
@@ -23,7 +23,7 @@ class LocalAssemblerInterface
 public:
     virtual ~LocalAssemblerInterface() = default;
 
-    virtual void assemble(std::size_t const id,
+    virtual void assemble(std::size_t const mesh_item_id,
                           NumLib::LocalToGlobalIndexMap const& dof_table,
                           double const t, GlobalVector const& x,
                           GlobalMatrix& M, GlobalMatrix& K,
diff --git a/ProcessLib/TES/TESLocalAssembler-impl.h b/ProcessLib/TES/TESLocalAssembler-impl.h
index 929df69743826c810dfaa014caafd8bfe7ca3c4d..7e96f6adb005aa822c9ff5bc9ac86b104a8f35f7 100644
--- a/ProcessLib/TES/TESLocalAssembler-impl.h
+++ b/ProcessLib/TES/TESLocalAssembler-impl.h
@@ -134,14 +134,14 @@ TESLocalAssembler<
 template <typename ShapeFunction_, typename IntegrationMethod_,
           unsigned GlobalDim>
 void TESLocalAssembler<ShapeFunction_, IntegrationMethod_, GlobalDim>::assemble(
-    std::size_t const id, NumLib::LocalToGlobalIndexMap const& dof_table,
-    double const /*t*/, GlobalVector const& x, GlobalMatrix& M, GlobalMatrix& K,
-    GlobalVector& b)
+    std::size_t const mesh_item_id,
+    NumLib::LocalToGlobalIndexMap const& dof_table, double const /*t*/,
+    GlobalVector const& x, GlobalMatrix& M, GlobalMatrix& K, GlobalVector& b)
 {
     _local_M.setZero();
     _local_K.setZero();
     _local_b.setZero();
-    auto const indices = NumLib::getIndices(id, dof_table);
+    auto const indices = NumLib::getIndices(mesh_item_id, dof_table);
     auto const local_x = x.get(indices);
 
     IntegrationMethod_ integration_method(_integration_order);
diff --git a/ProcessLib/TES/TESLocalAssembler.h b/ProcessLib/TES/TESLocalAssembler.h
index f15bace04307c4da20ef509922ee4fbe18d17478..f21ae2b37d77afb78d7cf67525b1c5b584820f3f 100644
--- a/ProcessLib/TES/TESLocalAssembler.h
+++ b/ProcessLib/TES/TESLocalAssembler.h
@@ -49,7 +49,7 @@ public:
                       unsigned const integration_order,
                       AssemblyParams const& asm_params);
 
-    void assemble(std::size_t const id,
+    void assemble(std::size_t const mesh_item_id,
                   NumLib::LocalToGlobalIndexMap const& dof_table,
                   double const t, GlobalVector const& x,
                   GlobalMatrix& M, GlobalMatrix& K,
diff --git a/NumLib/DOF/DOFTableUtil.h b/NumLib/DOF/DOFTableUtil.h
index cdfc5ac8458b9dd8dd8a04c1eebd96409083e2f9..546d614b67dd63d2f6a8614b969dfa9c5e627c3e 100644
--- a/NumLib/DOF/DOFTableUtil.h
+++ b/NumLib/DOF/DOFTableUtil.h
@@ -14,10 +14,11 @@
 
 namespace NumLib
 {
 //! Returns nodal indices for the item identified by \c id from the given
 //!  \c dof_table.
 std::vector<GlobalIndexType> getIndices(
-    std::size_t const id, NumLib::LocalToGlobalIndexMap const& dof_table);
+    std::size_t const mesh_item_id,
+    NumLib::LocalToGlobalIndexMap const& dof_table);
 }  // namespace NumLib
 
 #endif  // NUMLIB_DOF_DOFTABLEUTIL_H
@@ -14,10 +14,11 @@
 namespace NumLib
 {
-//! Returns nodal indices for the item identified by \c id from the given
-//!  \c dof_table.
+//! Returns nodal indices for the item identified by \c mesh_item_id from the
+//! given \c dof_table.
 std::vector<GlobalIndexType> getIndices(